@@ -6,6 +6,7 @@ mod utils;
 
 // NOTE: Unwrapping in a CLI is a no-no. Since throwing Rust developer errors at average users is mental overload
 fn main() {
+	pretty_env_logger::init();
 	use keys::key_names;
 
 	// Build CLI
@@ -23,12 +24,12 @@ fn main() {
 	let res = match matches.subcommand() {
 		Some((key, mtx)) => commands.get(key).unwrap().evaluate(mtx),
 		None => {
-			log::info!("vach-cli: Run `vach --help` for usage");
+			println!("vach-cli: Run `vach --help`");
 			Ok(())
-		}
+		},
 	};
 
 	if let Err(err) = res {
-		println!("Error: {}", err)
+		log::error!("{}", err)
 	};
 }
